@@ -51,6 +51,7 @@ from pprint import pformat
 import tools
 import fields
 import unicode_csv
+import inspect
 
 from constants_and_vars import STATS
 from constants_and_vars import FORMAT
@@ -62,6 +63,13 @@ from constants_and_vars import PORT
 from constants_and_vars import DB
 from constants_and_vars import PWD 
 from constants_and_vars import EXIT_OK, EXIT_WARNING, EXIT_ERROR, EXIT_UNKNOWN
+import callbacks
+
+try:
+    import progressbar
+    from progressbar import ETA, FileTransferSpeed, Percentage, ProgressBar, SimpleProgress
+except ImportError:
+    progressbar = None
 
 
 def _get_special_actions(model):
@@ -97,7 +105,6 @@ def _connect():
     return an uid and a opened socket linked to this connection
 
     """
-    global UID
     url = 'http://%s:%s/xmlrpc/' % (HOST, PORT)
     sock_common = xmlrpclib.ServerProxy(url + 'common', allow_none=True)
     UID = sock_common.login(DB, USER, PWD)
@@ -127,7 +134,6 @@ def connect(host=HOST, port=PORT, user=USER, pwd=PWD, dbname=DB):
     USER = user
     PWD = pwd
     DB = dbname
-    OERP = _connect()
 
 
 class Import_session(object):
@@ -149,7 +155,6 @@ class Import_session(object):
     """
 
     def __init__(self, **kw):
-        
         # Unique id of this import
         self._id = str(time.time())
         
@@ -187,7 +192,7 @@ class Import_session(object):
             'actual_line': 0,
             'col_num': 0,
             'line_num': 0,
-            'errors': 0,
+            'error': 0,
             'warning': 0,
             'line_skipped': 0,
             'line_done': 0,
@@ -1249,9 +1254,12 @@ formed, \n\n" % (model, attr)
             self._processed_lines = self._limit and self._processed_lines[:self._limit] or self._processed_lines
             self._logger.info("Limit: %s" % int(len(self._processed_lines)),
                     extra=STATS[self._id])
-            if self._preconfigure:
+            
+            filename_called = os.path.split(inspect.stack()[2][1])[-1]
+            if self._preconfigure and self._preconfigure != filename_called:
                 script_to_import, script_extention = os.path.splitext(self._preconfigure)
                 if script_extention == '.py':
+                    self._logger.info("Calling preconfigure script", extra=STATS[self._id])
                     self._processed_lines = __import__(script_to_import).main(self)
 
             # Init line incrementor
@@ -1469,6 +1477,9 @@ formed, \n\n" % (model, attr)
         # Open file, call preconfigure if given in arg
         #=======================================================================
         try:
+            if progressbar and not self.quiet and not self.verbose:
+                pbar = ProgressBar(widgets=['Processing line ', SimpleProgress(), ' (', Percentage(), ' | ', ETA(), ' | ', FileTransferSpeed(), ')'], maxval=len(self.lines)+1).start()
+
             for line in self.lines:
                 # Keeping stats 
                 STATS[self._id]['actual_line'] = line
@@ -1481,6 +1492,12 @@ formed, \n\n" % (model, attr)
                         extra=STATS[self._id])
                 self._launch_model_import()
 
+                if progressbar and not self.quiet and not self.verbose:
+                    pbar.update(int(STATS[self._id]['line_num']))
+
+            if progressbar and not self.quiet and not self.verbose:
+                pbar.finish()
+
             self._logger.info("END import", extra=STATS[self._id])
             
         except KeyboardInterrupt:
