@@ -50,6 +50,7 @@ Concretlty, it's such as simple as that::
 """
 from constants_and_vars import STATS
 import unicode_csv
+from datetime import datetime
 
 def get_line_from_table(csv_file, value, column, separator=',', quote='"', header=True):
     """Search for an equivalence between value from column ``col_referer``
@@ -155,7 +156,7 @@ def get_value_from_table(csv_file, col_referer=0, col_return=1,
 
     return _get_value_from_table
 
-def get_ids(model, fields, op='&'):
+def get_ids(model, fields, op='|'):
     """Return ``model`` which one or more ``fields`` matched column ``value``
    
     >>> 'partner_ids': Column(56, get_ids('res.partner.address', ['street', 'street2'], op='|'))
@@ -197,7 +198,7 @@ def get_ids(model, fields, op='&'):
     
     return _get_ids
 
-def get_id(model, fields, op='&'):
+def get_id(model, fields, op='|'):
     """Return ``model`` which one or more ``fields`` matched column ``value``
    
     >>> 'address_ids': (21, get_ids('res.partner', ['name']))
@@ -220,7 +221,7 @@ def get_id(model, fields, op='&'):
     
     return _get_id
 
-def get_objects(model, fields, op='&'):
+def get_objects(model, fields, op='|'):
     """Return ``model`` instance which ``fields``'s value matched ``value``
     
     >>> 'parent_name': Column(2, get_objects('res.partner.address', ['ref'])[0]['name'])
@@ -242,10 +243,10 @@ def get_objects(model, fields, op='&'):
 
     return _get_objects
 
-def get_object(model, fields, field, op='&'):
-    """Return ``model`` instance which ``fields``'s value matched ``value``
+def get_field(model, fields, field, op='|'):
+    """Return ``model``'s ``field`` field which ``fields``'s value matched ``value``
     
-    >>> 'parent_name': Column(2, get_object('res.partner.address', ['ref'])['name'])
+    >>> 'parent_name': Column(2, get_field('res.partner.address', ['ref'], 'name')
     ['Toto']
     
     :param model: The name of the model to search into
@@ -260,17 +261,17 @@ def get_object(model, fields, field, op='&'):
 
     """
     
-    def _get_object(*args):
+    def _get_field(*args):
         res = get_objects(model, fields, op=op)(*args)
         res = res and res[0]
         return res and field in res and res[field]
 
-    return _get_object
+    return _get_field
 
-def get_fields(model, fields, op='&'):
+def get_fields(model, fields, op='|'):
     """Return ``model`` instance which one or more ``fields`` matched column ``value``
     
-    >>> 'parent_name': Column(2, get_fields('res.partner.address', ['ref'])[0]['name'])
+    >>> 'parent_name': Column(2, get_fields('res.partner.address', ['ref']))
     'Toto'
     
     :param model: The name of the model to search into
@@ -314,11 +315,13 @@ def to_boolean(true='1', false='0', none=''):
 
     return _to_boolean
 
-def to_date():
+def to_date(formatted='%Y-%m-%d'):
     """Check for a valid date and convert if needed before returning the value
 
     >>> 'inserted_date': Column(6, to_date())
     
+    :param formatted: Format of this date
+    :type formatted: str
     :returns: str
 
     """
@@ -328,10 +331,10 @@ def to_date():
             date = str(value.split('\n')[0])
         except:
             pass
-        if date == '0000-00-00':
+        if date in ('0000-00-00', '0000/00/00', '00-00-0000', '00/00/0000'):
             return ''
-        else:
-            return date
+        date = datetime.strptime(date, formatted)
+        return date.strftime('%Y-%m-%d')
 
     return _to_date
 
